=====================
Scipion UNSTABLE REPO
=====================

**Scipion** is an image processing framework to obtain 3D models of
macromolecular complexes using Electron Microscopy (3DEM). It integrates
several software packages and presents an unified interface for both biologists
and developers. Scipion allows to execute workflows combining different
software tools, while taking care of formats and conversions. Additionally,
all steps are tracked and can be reproduced later on.

Want to learn more? [Go to our web site.](http://scipion.i2pc.es)


.. figure:: https://travis-ci.org/I2PC/scipion.svg?branch=devel
   :align: left
   :alt: Build Status

.. figure:: https://sonarcloud.io/api/project_badges/measure?project=Scipion&metric=alert_status
   :align: left
   :alt: Quality Gate

.. figure:: https://sonarcloud.io/api/project_badges/measure?project=Scipion&metric=sqale_index
   :align: left
   :alt: Technical debt

.. figure:: https://sonarcloud.io/api/project_badges/measure?project=Scipion&metric=bugs
   :align: left
   :alt: Bugs
